<?php

class ccc_price_uah implements crud_callback_chunk
{
    public function get_name()
    {
        return 'Price UAH';
    }
    
    public function get_options()
    {
        return FALSE;
    }
    
    public function get_schema()
    {
        return 'float(10,2)';
    }

    public function run()
    {
        return '\'price_uah\'';
    }
}
