<?php

class ccc_password implements crud_callback_chunk
{
    public function get_name()
    {
        return 'Password';
    }
    
    public function get_options()
    {
        return FALSE;
    }
    
    public function get_schema()
    {
        return 'varchar(255) CHARACTER SET utf8';
    }

    public function run()
    {
        return '\'rtgc_password\'';
    }
}
