<?php
$this->js_css->add_css('/' . $this->config->item('assets_folder') . '/' . $this->config->item('components_folder') . '/ciext/css/menu.css');
?>
<div class="sidebar-container navbar-collapse" id="left-menu">
    <div class="sidebar-header">
        <a href="/<?= $this->config->item('admin_page') ?>" class="logo_sidebar"></a>
    </div>
    <div class="sidebar-content">
        <ul class="sidebar-nav">
            <?php foreach ($items as $href => $lang) : ?>
                <li class="list-item" <?php echo ($href == $page) ? 'class="active"' : ''; ?>>
                    <a href="<?php echo $href; ?>"><?php echo $lang; ?></a>
                </li>
            <?php endforeach; ?>
        </ul>
    </div>

</div>