<?php

class ccc_spinner implements crud_callback_chunk
{
    public function get_name()
    {
        return 'Spinner';
    }
    
    public function get_options()
    {
        return FALSE;
    }
    
    public function get_schema()
    {
        return 'int(11)';
    }

    public function run()
    {
        return '\'spinner\'';
    }
}
